<?php

namespace Drupal\aiprompt_config\Entity;

use Drupal\aiprompt\Traits\AIPromptCommons;
use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * @ConfigEntityType(
 *   id = "aiprompt_config",
 *   label = @Translation("AI Prompt"),
 *   handlers = {
 *     "list_builder" = "Drupal\aiprompt_config\AIPromptConfigListBuilder",
 *     "form" = {
 *       "add" = "Drupal\aiprompt_config\Form\AIPromptConfigCreateForm",
 *       "edit" = "Drupal\aiprompt_config\Form\AIPromptConfigForm",
 *       "delete" = "Drupal\aiprompt_config\Form\AIPromptConfigDeleteForm",
 *     }
 *   },
 *   config_prefix = "aiprompt_config",
 *   admin_permission = "administer aiprompt configurations",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "add-form" = "/admin/config/aiprompt/add",
 *     "edit-form" = "/admin/config/aiprompt/{aiprompt_config}/edit",
 *     "delete-form" = "/admin/config/aiprompt/{aiprompt_config}/delete",
 *     "collection" = "/admin/config/aiprompt",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "segments",
 *     "notes"
 *   },
 * )
 */
class AIPromptConfig extends ConfigEntityBase {

  use AIPromptCommons;

  /**
   * The AI Prompt Configuration ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The AI Prompt Configuration label.
   *
   * @var string
   */
  protected $label;

  /**
   * The AI Prompt Configuration settings.
   *
   * @var array
   */
  protected $segments = [];

  /**
   * The Administrative notes for the AI Prompt Configuration.
   *
   * @var string
   */
  protected $notes;

  /**
   * The AI prompt plugin manager.
   *
   * @var \Drupal\aiprompt\AIPromptSegmentPluginManager
   */
  protected $aipromptSegmentPluginManager;

  /**
   * {@inheritdoc}
   */
  public function getNotes(): ?string {
    return $this->notes;
  }

  /**
   * {@inheritdoc}
   */
  public function setNotes(string $notes): void {
    $this->notes = $notes;
  }

  /**
   * {@inheritdoc}
   */
  public function getSegments(): array {
    return $this->segments;
  }

  /**
   * {@inheritdoc}
   */
  public function setSegments(array $segments): void {
    $this->segments = $segments;
  }

  /**
   * {@inheritdoc}
   */
  public function setSegment($segment, $machine_name = NULL) {
    if (empty($machine_name)) {
      $machine_name = $this->generateSegmentMachineName($segment['plugin_id']);
    }
    if (empty($this->segments)) {
      $this->segments = [];
    }
    $this->segments[$machine_name] = $segment;
  }

  /**
   * {@inheritdoc}
   */
  public function getSegment($machine_name = NULL) {

    $segment = !empty($machine_name) ? $this->segments[$machine_name] : [];

    $segment['settings']['aiprompt_id'] = $this->id();

    return $segment;
  }

  /**
   * {@inheritdoc}
   */
  public function deleteSegment($machine_name) {
    unset($this->segments[$machine_name]);
  }

}
